# swiflow

[![License](https://img.shields.io/github/license/TeamGraphix/swiflow)](https://github.com/TeamGraphix/swiflow?tab=Apache-2.0-1-ov-file)
[![test_rs](https://github.com/TeamGraphix/swiflow/actions/workflows/test_rs.yml/badge.svg)](https://github.com/TeamGraphix/swiflow/actions/workflows/test_rs.yml)
[![test_py](https://github.com/TeamGraphix/swiflow/actions/workflows/test_py.yml/badge.svg)](https://github.com/TeamGraphix/swiflow/actions/workflows/test_py.yml)
[![codecov](https://codecov.io/github/TeamGraphix/swiflow/graph/badge.svg?token=JPLJWWPNF4)](https://codecov.io/github/TeamGraphix/swiflow)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

Rust binding of generalized and pauli flow finding algorithms.

## License

This project is licensed under the Apache-2.0 License.
